__version__ = "0.4.2"

# arrays
from .arrays import (
    chunk,
    compact,
    difference,
    drop,
    dropRight,
    fill,
    indexOf,
    initial,
    pull
)

# maths
from .maths import (
    add,
    ceil,
    divide,
    floor,
    max,
    mean,
    min,
    multiply,
    substract,
    sum
)

# number
from .number import (
    clamp,
    inRange,
    random
)

# string
from .string import (
    camelCase,
    capitalize,
    endsWith,
    escape,
    lowerCase,
    lowerFirst,
    pad,
    padEnd,
    padStart,
    repeat,
    replace,
    startsWith
)